@@ -16,18 +16,20 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { Box, Heading, Flex, HStack, Skeleton } from "@chakra-ui/react";
+import { Box, Heading, Flex, HStack, Skeleton, Separator } from "@chakra-ui/react";
+import type { BoxProps } from "@chakra-ui/react";
 import { createListCollection } from "@chakra-ui/react/collection";
+import { useTranslation } from "react-i18next";
 import { FiDatabase } from "react-icons/fi";
 
 import type { AssetEventCollectionResponse, AssetEventResponse } from "openapi/requests/types.gen";
 import { StateBadge } from "src/components/StateBadge";
 import { Select } from "src/components/ui";
-import { pluralize } from "src/utils";
 
 import { DataTable } from "../DataTable";
 import type { CardDef, TableState } from "../DataTable/types";
 import { AssetEvent } from "./AssetEvent";
+import { AssetEventsFilter } from "./AssetEventsFilter";
 
 const cardDef = (assetId?: number): CardDef<AssetEventResponse> => ({
   card: ({ row }) => <AssetEvent assetId={assetId} event={row} />,
@@ -42,8 +44,9 @@ type AssetEventProps = {
   readonly isLoading?: boolean;
   readonly setOrderBy?: (order: string) => void;
   readonly setTableUrlState?: (state: TableState) => void;
+  readonly showFilters?: boolean;
   readonly tableUrlState?: TableState;
-  readonly title?: string;
+  readonly titleKey?: string;
 };
 
 export const AssetEvents = ({
@@ -52,26 +55,29 @@ export const AssetEvents = ({
   isLoading,
   setOrderBy,
   setTableUrlState,
+  showFilters = false,
   tableUrlState,
-  title,
-}: AssetEventProps) => {
+  titleKey,
+  ...rest
+}: AssetEventProps & BoxProps) => {
+  const { t: translate } = useTranslation(["dashboard", "common", "dag"]);
   const assetSortOptions = createListCollection({
     items: [
-      { label: "Newest first", value: "-timestamp" },
-      { label: "Oldest first", value: "timestamp" },
+      { label: translate("sortBy.newestFirst"), value: "-timestamp" },
+      { label: translate("sortBy.oldestFirst"), value: "timestamp" },
     ],
   });
 
   return (
-    <Box borderBottomWidth={0} borderRadius={5} borderWidth={1} ml={2}>
-      <Flex justify="space-between" mr={1} mt={0} pl={3} pt={1}>
+    <Box borderBottomWidth={0} borderRadius={8} borderWidth={1} p={4} py={2} {...rest}>
+      <Flex alignItems="center" justify="space-between">
         <HStack>
-          <StateBadge colorPalette="blue" fontSize="md" variant="solid">
+          <StateBadge colorPalette="brand" fontSize="md" variant="solid">
             <FiDatabase />
             {data?.total_entries ?? " "}
           </StateBadge>
           <Heading marginEnd="auto" size="md">
-            {pluralize(title ?? "Asset Event", data?.total_entries ?? 0, undefined, true)}
+            {translate(titleKey ?? "common:assetEvent", { count: data?.total_entries ?? 0 })}
           </Heading>
         </HStack>
         {setOrderBy === undefined ? undefined : (
@@ -81,6 +87,7 @@ export const AssetEvents = ({
             data-testid="asset-sort-duration"
             defaultValue={["-timestamp"]}
             onValueChange={(option) => setOrderBy(option.value[0] as string)}
+            size="sm"
             width={130}
           >
             <Select.Trigger>
@@ -97,6 +104,8 @@ export const AssetEvents = ({
           </Select.Root>
         )}
       </Flex>
+      {showFilters ? <AssetEventsFilter /> : null}
+      <Separator mt={2.5} />
       <DataTable
         cardDef={cardDef(assetId)}
         columns={[]}
@@ -104,7 +113,8 @@ export const AssetEvents = ({
         displayMode="card"
         initialState={tableUrlState}
         isLoading={isLoading}
-        modelName="Asset Event"
+        modelName={translate("common:assetEvent_one")}
+        noRowsMessage={translate("noAssetEvents")}
         onStateChange={setTableUrlState}
         skeletonCount={5}
         total={data?.total_entries}
